pub struct CreateWebhookParams {
pub channel_id: String,
pub name: String,
}Fields
channel_id: Stringname: StringTrait Implementations
Sourceimpl Clone for CreateWebhookParams
impl Clone for CreateWebhookParams
Sourcefn clone(&self) -> CreateWebhookParams
fn clone(&self) -> CreateWebhookParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateWebhookParams
impl Debug for CreateWebhookParams
Sourceimpl<'de> Deserialize<'de> for CreateWebhookParams
impl<'de> Deserialize<'de> for CreateWebhookParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CreateWebhookParams
impl JsonSchema for CreateWebhookParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CreateWebhookParams
impl RefUnwindSafe for CreateWebhookParams
impl Send for CreateWebhookParams
impl Sync for CreateWebhookParams
impl Unpin for CreateWebhookParams
impl UnsafeUnpin for CreateWebhookParams
impl UnwindSafe for CreateWebhookParams