pub struct DiscordAccountConfig {
pub bot_token: String,
}Fields
bot_token: StringTrait Implementations
Sourceimpl Clone for DiscordAccountConfig
impl Clone for DiscordAccountConfig
Sourcefn clone(&self) -> DiscordAccountConfig
fn clone(&self) -> DiscordAccountConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiscordAccountConfig
impl Debug for DiscordAccountConfig
Sourceimpl<'de> Deserialize<'de> for DiscordAccountConfig
impl<'de> Deserialize<'de> for DiscordAccountConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DiscordAccountConfig
impl JsonSchema for DiscordAccountConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscordAccountConfig
impl RefUnwindSafe for DiscordAccountConfig
impl Send for DiscordAccountConfig
impl Sync for DiscordAccountConfig
impl Unpin for DiscordAccountConfig
impl UnsafeUnpin for DiscordAccountConfig
impl UnwindSafe for DiscordAccountConfig