pub struct EmailMessage {
pub uid: u32,
pub subject: String,
pub from: String,
pub to: Vec<String>,
pub date: Option<String>,
pub body_text: Option<String>,
pub body_html: Option<String>,
pub is_seen: bool,
}Fields
uid: u32subject: Stringfrom: Stringto: Vec<String>date: Option<String>body_text: Option<String>body_html: Option<String>is_seen: boolTrait Implementations
Sourceimpl Clone for EmailMessage
impl Clone for EmailMessage
Sourcefn clone(&self) -> EmailMessage
fn clone(&self) -> EmailMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmailMessage
impl Debug for EmailMessage
Sourceimpl<'de> Deserialize<'de> for EmailMessage
impl<'de> Deserialize<'de> for EmailMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmailMessage
impl JsonSchema for EmailMessage
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmailMessage
impl RefUnwindSafe for EmailMessage
impl Send for EmailMessage
impl Sync for EmailMessage
impl Unpin for EmailMessage
impl UnsafeUnpin for EmailMessage
impl UnwindSafe for EmailMessage