pub struct ImapAccountConfig {
pub host: String,
pub port: u16,
pub username: String,
pub password: String,
}Fields
host: Stringport: u16username: Stringpassword: StringTrait Implementations
Sourceimpl Clone for ImapAccountConfig
impl Clone for ImapAccountConfig
Sourcefn clone(&self) -> ImapAccountConfig
fn clone(&self) -> ImapAccountConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImapAccountConfig
impl Debug for ImapAccountConfig
Sourceimpl<'de> Deserialize<'de> for ImapAccountConfig
impl<'de> Deserialize<'de> for ImapAccountConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ImapAccountConfig
impl JsonSchema for ImapAccountConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ImapAccountConfig
impl RefUnwindSafe for ImapAccountConfig
impl Send for ImapAccountConfig
impl Sync for ImapAccountConfig
impl Unpin for ImapAccountConfig
impl UnsafeUnpin for ImapAccountConfig
impl UnwindSafe for ImapAccountConfig