pub struct SendEmailParams {
pub to: Vec<String>,
pub cc: Option<Vec<String>>,
pub bcc: Option<Vec<String>>,
pub subject: String,
pub body: EmailBody,
pub attachments: Option<Vec<Attachment>>,
pub reply_to: Option<String>,
}Fields
to: Vec<String>cc: Option<Vec<String>>bcc: Option<Vec<String>>subject: Stringbody: EmailBodyattachments: Option<Vec<Attachment>>reply_to: Option<String>Trait Implementations
Sourceimpl Clone for SendEmailParams
impl Clone for SendEmailParams
Sourcefn clone(&self) -> SendEmailParams
fn clone(&self) -> SendEmailParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendEmailParams
impl Debug for SendEmailParams
Sourceimpl<'de> Deserialize<'de> for SendEmailParams
impl<'de> Deserialize<'de> for SendEmailParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendEmailParams
impl JsonSchema for SendEmailParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendEmailParams
impl RefUnwindSafe for SendEmailParams
impl Send for SendEmailParams
impl Sync for SendEmailParams
impl Unpin for SendEmailParams
impl UnsafeUnpin for SendEmailParams
impl UnwindSafe for SendEmailParams