pub struct SmtpAccountConfig {
pub host: String,
pub port: u16,
pub username: String,
pub password: String,
pub from_email: String,
}Fields
host: Stringport: u16username: Stringpassword: Stringfrom_email: StringTrait Implementations
Sourceimpl Clone for SmtpAccountConfig
impl Clone for SmtpAccountConfig
Sourcefn clone(&self) -> SmtpAccountConfig
fn clone(&self) -> SmtpAccountConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SmtpAccountConfig
impl Debug for SmtpAccountConfig
Sourceimpl<'de> Deserialize<'de> for SmtpAccountConfig
impl<'de> Deserialize<'de> for SmtpAccountConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SmtpAccountConfig
impl JsonSchema for SmtpAccountConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SmtpAccountConfig
impl RefUnwindSafe for SmtpAccountConfig
impl Send for SmtpAccountConfig
impl Sync for SmtpAccountConfig
impl Unpin for SmtpAccountConfig
impl UnsafeUnpin for SmtpAccountConfig
impl UnwindSafe for SmtpAccountConfig