pub struct SendBatchParams {
pub notifications: Vec<SendPushParams>,
}Fields
notifications: Vec<SendPushParams>Trait Implementations
Sourceimpl Clone for SendBatchParams
impl Clone for SendBatchParams
Sourcefn clone(&self) -> SendBatchParams
fn clone(&self) -> SendBatchParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendBatchParams
impl Debug for SendBatchParams
Sourceimpl<'de> Deserialize<'de> for SendBatchParams
impl<'de> Deserialize<'de> for SendBatchParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendBatchParams
impl JsonSchema for SendBatchParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendBatchParams
impl RefUnwindSafe for SendBatchParams
impl Send for SendBatchParams
impl Sync for SendBatchParams
impl Unpin for SendBatchParams
impl UnsafeUnpin for SendBatchParams
impl UnwindSafe for SendBatchParams