pub struct SendPushParams {
pub device_token: String,
pub platform: Platform,
pub title: String,
pub body: String,
pub data: Option<HashMap<String, String>>,
pub badge: Option<i32>,
pub sound: Option<String>,
}Fields
device_token: Stringplatform: Platformtitle: Stringbody: Stringdata: Option<HashMap<String, String>>badge: Option<i32>sound: Option<String>Trait Implementations
Sourceimpl Clone for SendPushParams
impl Clone for SendPushParams
Sourcefn clone(&self) -> SendPushParams
fn clone(&self) -> SendPushParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendPushParams
impl Debug for SendPushParams
Sourceimpl<'de> Deserialize<'de> for SendPushParams
impl<'de> Deserialize<'de> for SendPushParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendPushParams
impl JsonSchema for SendPushParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendPushParams
impl RefUnwindSafe for SendPushParams
impl Send for SendPushParams
impl Sync for SendPushParams
impl Unpin for SendPushParams
impl UnsafeUnpin for SendPushParams
impl UnwindSafe for SendPushParams