pub struct CheckStatusParams {
pub message_id: String,
}Fields
message_id: StringTrait Implementations
Sourceimpl Clone for CheckStatusParams
impl Clone for CheckStatusParams
Sourcefn clone(&self) -> CheckStatusParams
fn clone(&self) -> CheckStatusParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckStatusParams
impl Debug for CheckStatusParams
Sourceimpl<'de> Deserialize<'de> for CheckStatusParams
impl<'de> Deserialize<'de> for CheckStatusParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CheckStatusParams
impl JsonSchema for CheckStatusParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CheckStatusParams
impl RefUnwindSafe for CheckStatusParams
impl Send for CheckStatusParams
impl Sync for CheckStatusParams
impl Unpin for CheckStatusParams
impl UnsafeUnpin for CheckStatusParams
impl UnwindSafe for CheckStatusParams