pub struct SendMessageParams {
pub chat_id: String,
pub text: String,
pub parse_mode: Option<ParseMode>,
pub reply_to_message_id: Option<i64>,
}Fields
chat_id: Stringtext: Stringparse_mode: Option<ParseMode>reply_to_message_id: Option<i64>Trait Implementations
Sourceimpl Clone for SendMessageParams
impl Clone for SendMessageParams
Sourcefn clone(&self) -> SendMessageParams
fn clone(&self) -> SendMessageParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendMessageParams
impl Debug for SendMessageParams
Sourceimpl<'de> Deserialize<'de> for SendMessageParams
impl<'de> Deserialize<'de> for SendMessageParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendMessageParams
impl JsonSchema for SendMessageParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendMessageParams
impl RefUnwindSafe for SendMessageParams
impl Send for SendMessageParams
impl Sync for SendMessageParams
impl Unpin for SendMessageParams
impl UnsafeUnpin for SendMessageParams
impl UnwindSafe for SendMessageParams