pub struct SendPhotoParams {
pub chat_id: String,
pub photo: String,
pub caption: Option<String>,
}Fields
chat_id: Stringphoto: Stringcaption: Option<String>Trait Implementations
Sourceimpl Clone for SendPhotoParams
impl Clone for SendPhotoParams
Sourcefn clone(&self) -> SendPhotoParams
fn clone(&self) -> SendPhotoParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SendPhotoParams
impl Debug for SendPhotoParams
Sourceimpl<'de> Deserialize<'de> for SendPhotoParams
impl<'de> Deserialize<'de> for SendPhotoParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SendPhotoParams
impl JsonSchema for SendPhotoParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SendPhotoParams
impl RefUnwindSafe for SendPhotoParams
impl Send for SendPhotoParams
impl Sync for SendPhotoParams
impl Unpin for SendPhotoParams
impl UnsafeUnpin for SendPhotoParams
impl UnwindSafe for SendPhotoParams