Method enum schema trait for activations
Provides a trait that method enums can implement to support schema generation with const discriminators for the method field.
Traits
- Method
Enum Schema - Trait for method enums that can generate schema with const discriminators