pub struct ActivationInfo {
pub namespace: String,
pub version: String,
pub description: String,
pub methods: Vec<String>,
}Fields
namespace: Stringversion: Stringdescription: Stringmethods: Vec<String>Trait Implementations
Sourceimpl Clone for ActivationInfo
impl Clone for ActivationInfo
Sourcefn clone(&self) -> ActivationInfo
fn clone(&self) -> ActivationInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActivationInfo
impl Debug for ActivationInfo
Sourceimpl<'de> Deserialize<'de> for ActivationInfo
impl<'de> Deserialize<'de> for ActivationInfo
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ActivationInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ActivationInfo, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActivationInfo
impl JsonSchema for ActivationInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for ActivationInfo
impl Serialize for ActivationInfo
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more